The Bayes factor (BF10) for the one-sample t-test.
Arguments
tval
Observed t-value from the one-sample t-test.
df
Degrees of freedom for the t-test.
model
Statistical model of the analysis prior under the alternative hypothesis: Normal distribution ("Normal"), Normal moment ("NLP"), or scaled t ("t-distribution").
location
Location parameter for the analysis prior under the alternative hypothesis.
scale
Scale parameter for the analysis prior under the alternative hypothesis.
dff
Degrees of freedom for the analysis prior under the alternative hypothesis (if applicable).
hypothesis
The hypothesis being tested: two-sided ("!="), right-sided (">"), or left-sided ("<").
e
Optional numeric vector specifying bounds for an interval null; used if interval BF is calculated.